@@ -10,7 +10,8 @@ function _possibleConstructorReturn(self, call) { if (!self) { throw new Referen
 
 function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }
 
-import React, { PropTypes, Component } from 'react';
+import React, { Component } from 'react';
+import PropTypes from 'prop-types';
 
 var BASE_STYLE = {
   display: "inline-block",
@@ -60,7 +61,7 @@ var Button = function (_Component) {
   }
 
   _createClass(Button, [{
-    key: "render",
+    key: 'render',
     value: function render() {
       var _this2 = this;
 
@@ -72,12 +73,12 @@ var Button = function (_Component) {
           customStyleHover = _props.styleHover,
           children = _props.children,
           size = _props.size,
-          rest = _objectWithoutProperties(_props, ["type", "style", "styleHover", "children", "size"]);
+          rest = _objectWithoutProperties(_props, ['type', 'style', 'styleHover', 'children', 'size']);
 
       var styleMerged = Object.assign({}, BASE_STYLE, BASE_STYLE_SIZE[size], hover ? customStyleHover : customStyle);
 
       return React.createElement(
-        "button",
+        'button',
         _extends({
           type: type,
           onMouseEnter: function onMouseEnter(e) {
