@@ -1,4 +1,5 @@
-import React, { PropTypes } from 'react';
+import React from 'react';
+import PropTypes from 'prop-types';
 
 var STYLE = {
   stroke: "#0096fd",
@@ -26,19 +27,19 @@ export default function Ruler(_ref) {
       transform = _ref.transform;
 
 
-  var distanceText = length.toFixed(2) + " " + unit;
+  var distanceText = length.toFixed(2) + ' ' + unit;
 
   return React.createElement(
-    "g",
+    'g',
     { transform: transform },
     React.createElement(
-      "text",
-      { x: length / 2, y: "-3", transform: "scale(1, -1)", style: STYLE_TEXT },
+      'text',
+      { x: length / 2, y: '-3', transform: 'scale(1, -1)', style: STYLE_TEXT },
       distanceText
     ),
-    React.createElement("line", { x1: "0", y1: "-5", x2: "0", y2: "5", style: STYLE }),
-    React.createElement("line", { x1: length, y1: "-5", x2: length, y2: "5", style: STYLE }),
-    React.createElement("line", { x1: "0", y1: "0", x2: length, y2: "0", style: STYLE })
+    React.createElement('line', { x1: '0', y1: '-5', x2: '0', y2: '5', style: STYLE }),
+    React.createElement('line', { x1: length, y1: '-5', x2: length, y2: '5', style: STYLE }),
+    React.createElement('line', { x1: '0', y1: '0', x2: length, y2: '0', style: STYLE })
   );
 }
 
