@@ -53,7 +53,6 @@ const ASIDE_STYLE = {
 export default function Toolbar({state, width, height, toolbarButtons, allowProjectFileSupport}, {
   projectActions,
   viewer2DActions,
-  editingActions,
   viewer3DActions,
   linesActions,
   holesActions,
@@ -197,7 +196,6 @@ Toolbar.propTypes = {
 Toolbar.contextTypes = {
   projectActions: PropTypes.object.isRequired,
   viewer2DActions: PropTypes.object.isRequired,
-  editingActions: PropTypes.object.isRequired,
   viewer3DActions: PropTypes.object.isRequired,
   linesActions: PropTypes.object.isRequired,
   holesActions: PropTypes.object.isRequired,
