@@ -15,6 +15,9 @@ export const ROLLBACK = 'ROLLBACK';
 export const SET_PROJECT_PROPERTIES = 'SET_PROJECT_PROPERTIES';
 export const OPEN_PROJECT_CONFIGURATOR = 'OPEN_PROJECT_CONFIGURATOR';
 export const INIT_CATALOG = 'INIT_CATALOG';
+export const UPDATE_MOUSE_COORDS = 'UPDATE_MOUSE_COORDS';
+export const UPDATE_ZOOM_SCALE = 'UPDATE_ZOOM_SCALE';
+export const TOGGLE_SNAP = 'TOGGLE_SNAP';
 
 // ACTIONS viewer2D
 export const SELECT_TOOL_ZOOM_IN = 'SELECT_TOOL_ZOOM_IN';
@@ -89,7 +92,10 @@ export const PROJECT_ACTIONS = {
   ROLLBACK,
   SET_PROJECT_PROPERTIES,
   OPEN_PROJECT_CONFIGURATOR,
-  INIT_CATALOG
+  INIT_CATALOG,
+  UPDATE_MOUSE_COORDS,
+  UPDATE_ZOOM_SCALE,
+  TOGGLE_SNAP
 };
 
 export const VIEWER2D_ACTIONS = {
@@ -156,7 +162,7 @@ export const VERTEX_ACTIONS = {
 };
 
 //MODES
-export const MODE_IDLE = 'IDLE';
+export const MODE_IDLE = 'MODE_IDLE';
 export const MODE_2D_ZOOM_IN = 'MODE_2D_ZOOM_IN';
 export const MODE_2D_ZOOM_OUT = 'MODE_2D_ZOOM_OUT';
 export const MODE_2D_PAN = 'MODE_2D_PAN';
@@ -176,6 +182,42 @@ export const MODE_FITTING_IMAGE = 'MODE_FITTING_IMAGE';
 export const MODE_VIEWING_CATALOG = 'MODE_VIEWING_CATALOG';
 export const MODE_CONFIGURING_PROJECT = 'MODE_CONFIGURING_PROJECT';
 
+//Thinking about it...
+//https://developer.mozilla.org/it/docs/Web/JavaScript/Reference/Global_Objects/Proxy
+/*
+let MODE_DEF = [
+  'IDLE',
+  '2D_ZOOM_IN',
+  '2D_ZOOM_OUT',
+  '2D_PAN',
+  '3D_VIEW',
+  '3D_FIRST_PERSON',
+  'WAITING_DRAWING_LINE',
+  'DRAGGING_LINE',
+  'DRAGGING_VERTEX',
+  'DRAGGING_ITEM',
+  'DRAGGING_HOLE',
+  'DRAWING_LINE',
+  'DRAWING_HOLE',
+  'DRAWING_ITEM',
+  'ROTATING_ITEM',
+  'UPLOADING_IMAGE',
+  'FITTING_IMAGE',
+  'VIEWING_CATALOG',
+  'CONFIGURING_PROJECT',
+];
+
+export const MODE = new Proxy( MODE_DEF, { get: (target, name) => { return target.indexOf(name) !== -1 ? name : null } } );
+*/
+
+export const MODE_SNAPPING = [
+  MODE_IDLE, MODE_2D_ZOOM_IN, MODE_2D_ZOOM_OUT, MODE_2D_PAN,
+  MODE_WAITING_DRAWING_LINE, MODE_DRAWING_LINE, MODE_DRAWING_HOLE,
+  MODE_DRAWING_ITEM, MODE_DRAGGING_LINE, MODE_DRAGGING_VERTEX,
+  MODE_DRAGGING_ITEM, MODE_DRAGGING_HOLE, MODE_FITTING_IMAGE,
+  MODE_UPLOADING_IMAGE, MODE_ROTATING_ITEM
+];
+
 //UNITS
 export const UNIT_MILLIMETER = 'mm';
 export const UNIT_CENTIMETER = 'cm';
